@@ -1,7 +1,7 @@
 import warnings
 
 from django.conf import settings
-from django.db import DEFAULT_DB_ALIAS, router, connections
+from django.db import connections
 from django.utils.module_loading import import_string
 
 
@@ -15,14 +15,8 @@ def get_migration_class_from_engine(engine):
     return import_string(path)
 
 
-def migrate_help_text_to_database(app_config,
-                                  using=DEFAULT_DB_ALIAS, **kwargs):
+def migrate_app_models_help_text_to_database(app_models, using):
     engine = settings.DATABASES[using]['ENGINE']
-
-    app_label = app_config.label
-    if not router.allow_migrate(using, app_label):
-        return
-    app_models = app_config.get_models()
     try:
         migration_class = get_migration_class_from_engine(engine)
     except ImportError:
